@@ -40,16 +40,23 @@ Kamoso::~Kamoso()
 
 }
 
-const QString Kamoso::takePhoto()
+QUrl Kamoso::fileNameSuggestion(const QUrl &saveUrl, const QString &name, const QString& extension) const
 {
-    const QUrl saveUrl = Settings::saveUrl();
-    const QString initialName = QStringLiteral("picture.jpg");
-    QUrl path = saveUrl.toString() + '/' + initialName;
+    const QString date = QDateTime::currentDateTime().toString(QStringLiteral("yyyy-mm-dd_hh-mm-ss"));
+    const QString initialName =  QStringLiteral("%1_%2.%3").arg(name, date, extension);
+
+    QUrl path(saveUrl.toString() + '/' + initialName);
 
     if (path.isLocalFile() && QFile::exists(path.toLocalFile())) {
         path = saveUrl.toString() + '/' + KIO::suggestName(saveUrl, initialName);
     }
 
+    return path;
+}
+
+const QString Kamoso::takePhoto()
+{
+    const QUrl path = fileNameSuggestion(Settings::saveUrl(), "picture", "jpg");
     m_webcamControl->takePhoto(path);
 
     return path.toDisplayString();
@@ -62,14 +69,7 @@ void Kamoso::startRecording()
 
 void Kamoso::stopRecording()
 {
-    const QUrl saveUrl = Settings::saveUrl();
-    const QString initialName = QStringLiteral("video.mkv");
-
-    QUrl path = saveUrl.toString() + '/' + initialName;
-
-    if (path.isLocalFile() && QFile::exists(path.toLocalFile())) {
-        path = saveUrl.toString() + '/' + KIO::suggestName(saveUrl, initialName);
-    }
+    const QUrl path = fileNameSuggestion(Settings::saveVideos(), "video", "mkv");
 
     KJob *job = KIO::move(QUrl::fromLocalFile(m_webcamControl->stopRecording()), path);
     job->start();
